# The Things Network_python_client

[![codecov](https://codecov.io/gh/angelnu/thethingsnetwork_python_client/graph/badge.svg?token=yUTImnfbUL)](https://codecov.io/gh/angelnu/thethingsnetwork_python_client)

A python client to fetch/receive and parse uplink messages from The Things Network

This is a WIP package as it was before part of a custom [Home Assistant integration](https://github.com/angelnu/home_assistant_thethingsnetwork)

WIP - coverage dummy

## Thanks

This package structure and pipeline is derived from the [zwave-js-server-python](https://github.com/home-assistant-libs/zwave-js-server-python) package.
